@@ -4,28 +4,21 @@ package ORLite;
 
 use 5.006;
 use strict;
-use Carp              ();
-use File::Spec   0.80 ();
-use File::Temp   0.20 ();
-use File::Path   2.04 ();
-use File::Basename  0 ();
-use Params::Util 0.33 ();
-use DBI         1.607 ();
-use DBD::SQLite  1.25 ();
+use Carp         ();
+use File::Spec   ();
+use File::Temp   ();
+use Params::Util qw{ _STRING _CLASS _HASH };
+use DBI          ();
 
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '1.29_03';
-}
+	$VERSION = '1.16';
 
-# Support for the 'prune' option
-my @PRUNE = ();
-END {
-	foreach ( reverse @PRUNE ) {
-		next unless -e $_;
-		require File::Remove;
-		File::Remove::remove( \1, $_ );
-	}
+	# DBD::SQLite has a bug that generates a spurious warning
+	# at compile time, so we need to temporarily disable them.
+	# Remove this hack once DBD::SQLite fixes the bug.
+	local $^W = 0;
+	require DBD::SQLite;
 }
 
 
@@ -40,14 +33,14 @@ sub import {
 
 	# Check for debug mode
 	my $DEBUG = 0;
-	if ( defined Params::Util::_STRING($_[-1]) and $_[-1] eq '-DEBUG' ) {
+	if ( defined _STRING($_[-1]) and $_[-1] eq '-DEBUG' ) {
 		$DEBUG = 1;
 		pop @_;
 	}
 
 	# Check params and apply defaults
 	my %params;
-	if ( defined Params::Util::_STRING($_[1]) ) {
+	if ( defined _STRING($_[1]) ) {
 		# Support the short form "use ORLite 'db.sqlite'"
 		%params = (
 			file     => $_[1],
@@ -55,7 +48,7 @@ sub import {
 			package  => undef, # Automatic
 			tables   => 1,
 		);
-	} elsif ( Params::Util::_HASHLIKE($_[1]) ) {
+	} elsif ( _HASH($_[1]) ) {
 		%params = %{ $_[1] };
 	} else {
 		Carp::croak("Missing, empty or invalid params HASH");
@@ -64,7 +57,7 @@ sub import {
 		$params{create} = 0;
 	}
 	unless (
-		defined Params::Util::_STRING($params{file})
+		defined _STRING($params{file})
 		and (
 			$params{create}
 			or
@@ -82,32 +75,17 @@ sub import {
 	unless ( defined $params{package} ) {
 		$params{package} = scalar caller;
 	}
-	unless ( Params::Util::_CLASS($params{package}) ) {
+	unless ( _CLASS($params{package}) ) {
 		Carp::croak("Missing or invalid package class");
 	}
 
 	# Connect to the database
 	my $file     = File::Spec->rel2abs($params{file});
-	my $created  = ! -f $params{file};
-	if ( $created ) {
-		# Create the parent directory
-		my $dir = File::Basename::dirname($file);
-		unless ( -d $dir ) {
-			my @dirs = File::Path::mkpath( $dir, { verbose => 0 } );
-			$class->prune(@dirs) if $params{prune};
-		}
-		$class->prune($file) if $params{prune};
-	}
 	my $pkg      = $params{package};
 	my $readonly = $params{readonly};
 	my $dsn      = "dbi:SQLite:$file";
 	my $dbh      = DBI->connect($dsn);
 
-	# Schema creation support
-	if ( $created and Params::Util::_CODELIKE($params{create}) ) {
-		$params{create}->( $dbh );
-	}
-
 	# Check the schema version before generating
 	my $version  = $dbh->selectrow_arrayref('pragma user_version')->[0];
 	if ( exists $params{user_version} and $version != $params{user_version} ) {
@@ -115,34 +93,23 @@ sub import {
 	}
 
 	# Generate the support package code
-	my $code = <<"END_PERL";
+	my $code  = <<"END_PERL";
 package $pkg;
 
 use strict;
-use Carp ();
-use DBI  ();
 
 my \$DBH = undef;
 
-sub orlite { '$VERSION' }
-
-sub sqlite { '$file' }
-
 sub dsn { '$dsn' }
 
 sub dbh {
-	\$DBH or \$_[0]->connect;
+	\$DBH or
+	\$_[0]->connect or
+	Carp::croak("connect: \$DBI::errstr");
 }
 
 sub connect {
-	DBI->connect( \$_[0]->dsn, undef, undef, {
-		PrintError => 0,
-		RaiseError => 1,
-	} );
-}
-
-sub prepare {
-	shift->dbh->prepare(\@_);
+	DBI->connect(\$_[0]->dsn);
 }
 
 sub do {
@@ -173,29 +140,23 @@ sub selectrow_hashref {
 	shift->dbh->selectrow_hashref(\@_);
 }
 
+sub prepare {
+	shift->dbh->prepare(\@_);
+}
+
 sub pragma {
 	\$_[0]->do("pragma \$_[1] = \$_[2]") if \@_ > 2;
 	\$_[0]->selectrow_arrayref("pragma \$_[1]")->[0];
 }
 
-sub iterate {
-	my \$class = shift;
-	my \$call  = pop;
-	my \$sth   = \$class->prepare( shift );
-	\$sth->execute( \@_ );
-	while ( \$_ = \$sth->fetchrow_arrayref ) {
-		\$call->() or last;
-	}
-	\$sth->finish;
-}
-
 END_PERL
 
 	# Add transaction support if not readonly
 	$code .= <<"END_PERL" unless $readonly;
 sub begin {
 	\$DBH or
-	\$DBH = \$_[0]->connect;
+	\$DBH = \$_[0]->connect or
+	Carp::croak("connect: \$DBI::errstr");
 	\$DBH->begin_work;
 }
 
@@ -207,16 +168,6 @@ sub commit {
 	return 1;
 }
 
-sub commit_begin {
-	if ( \$DBH ) {
-		\$DBH->commit;
-		\$DBH->begin_work;
-	} else {
-		\$_[0]->begin;
-	}
-	return 1;
-}
-
 sub rollback {
 	\$DBH or return 1;
 	\$DBH->rollback;
@@ -225,24 +176,14 @@ sub rollback {
 	return 1;
 }
 
-sub rollback_begin {
-	if ( \$DBH ) {
-		\$DBH->rollback;
-		\$DBH->begin_work;
-	} else {
-		\$_[0]->begin;
-	}
-	return 1;
-}
-
 END_PERL
 
 	# Optionally generate the table classes
 	if ( $params{tables} ) {
 		# Capture the raw schema information
 		my $tables = $dbh->selectall_arrayref(
-			'select * from sqlite_master where name not like ? and type = ?',
-			{ Slice => {} }, 'sqlite_%', 'table',
+			'select * from sqlite_master where type = ?',
+			{ Slice => {} }, 'table',
 		);
 		foreach my $table ( @$tables ) {
 			$table->{columns} = $dbh->selectall_arrayref(
@@ -259,8 +200,8 @@ END_PERL
 			$table->{cindex} = map { $_->{name} => $_ } @columns;
 
 			# Discover the primary key
-			@{$table->{pk}}  = map($_->{name}, grep { $_->{pk} } @columns);
-			$table->{pks}    = scalar(@{$table->{pk}});
+			$table->{pk}     = List::Util::first { $_->{pk} } @columns;
+			$table->{pk}     = $table->{pk}->{name} if $table->{pk};
 
 			# What will be the class for this table
 			$table->{class}  = ucfirst lc $table->{name};
@@ -277,7 +218,6 @@ END_PERL
 				"insert into $table->{name}" .
 				"( $table->{sql}->{cols} )"  .
 				" values ( $table->{sql}->{vals} )";
-			$sql->{where_pk}    = join(' and ', map("$_ = ?", @{$table->{pk}}))
 		}
 
 		# Generate the foreign key metadata
@@ -301,18 +241,14 @@ END_PERL
 		# Generate the per-table code
 		foreach my $table ( @$tables ) {
 			# Generate the accessors
-			my $sql     = $table->{sql};
-			my @columns = @{ $table->{columns} };
-			my @names   = map { $_->{name} } @columns;
+			my $sql       = $table->{sql};
+			my @columns   = @{ $table->{columns} };
+			my @names     = map { $_->{name} } @columns;
 
 			# Generate the elements in all packages
 			$code .= <<"END_PERL";
 package $table->{class};
 
-sub base { '$pkg' }
-
-sub table { '$table->{name}' }
-
 sub select {
 	my \$class = shift;
 	my \$sql   = '$sql->{select} ';
@@ -329,50 +265,14 @@ sub count {
 	$pkg->selectrow_array( \$sql, {}, \@_ );
 }
 
-sub iterate {
-	my \$class = shift;
-	my \$call  = pop;
-	my \$sql   = '$sql->{select} ';
-	   \$sql  .= shift if \@_;
-	my \$sth   = $pkg->prepare( \$sql );
-	\$sth->execute( \@_ );
-	while ( \$_ = \$sth->fetchrow_hashref ) {
-		bless( \$_, '$table->{class}' );
-		\$call->() or last;
-	}
-	\$sth->finish;
-}
-
 END_PERL
 
-			# Add the primary key based single object loader
-			if ( $table->{pks} ) {
-				$code .= <<"END_PERL";
-sub load {
-	my \$class = shift;
-	my \$row   = $pkg->selectrow_hashref(
-		'$sql->{select} where $sql->{where_pk}',
-		undef, \@_,
-	);
-	unless ( \$row ) {
-		Carp::croak("$table->{class} row does not exist");
-	}
-	bless( \$row, '$table->{class}' );
-}
-
-END_PERL
-			}
-
 			# Generate the elements for tables with primary keys
 			if ( defined $table->{pk} and ! $readonly ) {
 				my $nattr = join "\n", map { "\t\t$_ => \$attr{$_}," } @names;
 				my $iattr = join "\n", map { "\t\t\$self->{$_},"       } @names;
-				my $fill_pk = scalar @{$table->{pk}} == 1 
-					? "\t\$self->{$table->{pk}->[0]} = \$dbh->func('last_insert_rowid') unless \$self->{$table->{pk}->[0]};"
-					: q{};
-				my $where_pk      = join(' and ', map("$_ = ?", @{$table->{pk}}));
-				my $where_pk_attr = join("\n", map("\t\t\$self->{$_},", @{$table->{pk}}));
 				$code .= <<"END_PERL";
+
 sub new {
 	my \$class = shift;
 	my \%attr  = \@_;
@@ -391,16 +291,15 @@ sub insert {
 	\$dbh->do('$sql->{insert}', {},
 $iattr
 	);
-$fill_pk	
+	\$self->{$table->{pk}} = \$dbh->func('last_insert_rowid') unless \$self->{$table->{pk}};
 	return \$self;
 }
 
 sub delete {
 	my \$self = shift;
 	return $pkg->do(
-		'delete from $table->{name} where $where_pk',
-		{}, 
-$where_pk_attr		
+		'delete from $table->{name} where $table->{pk} = ?',
+		{}, \$self->{$table->{pk}},
 	) if ref \$self;
 	Carp::croak("Must use truncate to delete all rows") unless \@_;
 	return $pkg->do(
@@ -409,10 +308,6 @@ $where_pk_attr
 	);
 }
 
-sub truncate {
-	$pkg->do( 'delete from $table->{name}', {} );
-}
-
 END_PERL
 
 			}
@@ -420,7 +315,7 @@ END_PERL
 		# Generate the accessors
 		$code .= join "\n\n", map { $_->{fk} ? <<"END_DIRECT" : <<"END_ACCESSOR" } @columns;
 sub $_->{name} {
-	($_->{fk}->[1]->{class}\->select('where $_->{fk}->[1]->{pk}->[0] = ?', \$_[0]->{$_->{name}}))[0];
+	($_->{fk}->[1]->{class}\->select('where $_->{fk}->[1]->{pk} = ?', \$_[0]->{$_->{name}}))[0];
 }
 END_DIRECT
 sub $_->{name} {
@@ -432,15 +327,25 @@ END_ACCESSOR
 	}
 	$dbh->disconnect;
 
-	# Add any custom code to the end
-	if ( defined $params{append} ) {
-		$code .= "\npackage $pkg;\n" if $params{tables};
-		$code .= "\n$params{append}";
-	}
-
 	# Load the code
 	if ( $DEBUG ) {
-		dval("$code\n\n1;\n");
+		# Compile the combined code via a temp file
+		my ($fh, $filename) = File::Temp::tempfile();
+		$fh->print("$code\n\n1;\n");
+		close $fh;
+		require $filename;
+		unlink $filename;
+
+		# Print the debugging output
+		my @trace = map {
+			s/\s*[{;]$//;
+			s/^s/  s/;
+			s/^p/\np/;
+			"$_\n"
+		} grep {
+			/^(?:package|sub)\b/
+		} split /\n/, $code;
+		print STDERR @trace, "\n$pkg code saved as $filename\n\n";
 	} else {
 		eval("$code\n\n1;\n");
 		die $@ if $@;
@@ -449,33 +354,6 @@ END_ACCESSOR
 	return 1;
 }
 
-sub dval {
-	# Write the code to the temp file
-	my ($fh, $filename) = File::Temp::tempfile();
-	$fh->print($_[0]);
-	close $fh;
-	require $filename;
-	unlink $filename;
-
-	# Print the debugging output
-	my @trace = map {
-		s/\s*[{;]$//;
-		s/^s/  s/;
-		s/^p/\np/;
-		"$_\n"
-	} grep {
-		/^(?:package|sub)\b/
-	} split /\n/, $_[0];
-	# print STDERR @trace, "\nCode saved as $filename\n\n";
-
-	return 1;
-}
-
-sub prune {
-	my $class = shift;
-	push @PRUNE, map { File::Spec->rel2abs($_) } @_;
-}
-
 1;
 
 __END__
@@ -490,8 +368,6 @@ ORLite - Extremely light weight SQLite-specific ORM
 
   package Foo;
   
-  # Simplest possible usage
-  
   use strict;
   use ORLite 'data/sqlite.db';
   
@@ -499,28 +375,10 @@ ORLite - Extremely light weight SQLite-specific ORM
      'where first_name = ?',
      'Adam',
   );
-  
-  package Bar;
-  
-  # All available options enabled
-  # Some options shown are mutually exclusive, this would not actually run
-  
-  use ORLite {
-      package      => 'My::ORM',
-      file         => 'data/sqlite.db',
-      user_version => 12,
-      tables       => [ 'table1', 'table2' ],
-      readonly     => 1,
-      prune        => 1,
-      create       => sub {
-          my $dbh = shift;
-          $dbh->do('CREATE TABLE foo ( bar TEXT NOT NULL )');
-      },
-  );
 
 =head1 DESCRIPTION
 
-L<SQLite> is a light single file SQL database that provides an
+L<SQLite> is a light weight single file SQL database that provides an
 excellent platform for embedded storage of structured data.
 
 However, while it is superficially similar to a regular server-side SQL
@@ -539,13 +397,12 @@ L<DBIx::Class>.
 What this situation would seem to need is an object-relation system that is
 designed specifically for SQLite and is aligned with its idiosyncracies.
 
-ORLite is an object-relation system specifically tailored for SQLite that
-follows many of the same principles as the ::Tiny series of modules and
-has a design and feature set that aligns directly to the capabilities of
-SQLite.
+ORLite is an object-relation system specifically for SQLite that follows
+many of the same principles as the ::Tiny series of modules and has a
+design that aligns directly to the capabilities of SQLite.
 
 Further documentation will be available at a later time, but the synopsis
-gives a pretty good idea of how it works.
+gives a pretty good idea of how it will work.
 
 =head1 How it Works
 
@@ -772,13 +629,9 @@ For other issues, contact the author.
 
 Adam Kennedy E<lt>adamk@cpan.orgE<gt>
 
-=head1 SEE ALSO
-
-L<ORLite::Mirror>, L<ORLite::Migrate>
-
 =head1 COPYRIGHT
 
-Copyright 2008 - 2009 Adam Kennedy.
+Copyright 2008 Adam Kennedy.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
