@@ -8,8 +8,8 @@ use File::Spec::Functions ':ALL';
 
 use vars qw{$VERSION @ISA @EXPORT};
 BEGIN {
-	$VERSION = '1.29_03';
-	@ISA     = 'Exporter';
+        $VERSION = '1.16';
+	@ISA     = qw{ Exporter };
 	@EXPORT  = qw{ test_db connect_ok create_ok };
 }
 
